course-prerequisite plugin for `Grvlms <https://docs.grvlms.overhang.io>`__
===================================================================================
::
    This feature will enable course prerequisite in studio. 

Installation
------------

::

    pip install git+https://github.com/groovetch/grvlms-course-prerequisite

Usage
-----

::

    grvlms plugins enable course-prerequisite
    

License
-------

This software is licensed under the terms of the AGPLv3.